@@ -49,13 +49,16 @@ class Docker(object):
     nb_traits = min(50, int(50*done/total))
     sys.stdout.write('\r' + prefix + ' [')
     line_len += len(prefix) + 2
-    for i in range(1, 50, 1):
-      if nb_traits == 50 and i == nb_traits - 1:
-        sys.stdout.write('>')
-      elif i <= nb_traits:
-        sys.stdout.write('=')
-      else:
-        sys.stdout.write(' ')
+    if nb_traits < 50:
+      for i in range(1, 50, 1):
+        if i == nb_traits:
+          sys.stdout.write('>')
+        elif i < nb_traits:
+          sys.stdout.write('=')
+        else:
+          sys.stdout.write(' ')
+    else:
+      sys.stdout.write('=' * 50)
     tail = '] {}/{}'.format(done, total)
     line_len += len(tail) + 50
     sys.stdout.write(tail)
